// ==================================================================
// file: vector_sum.h
// date: october 2012
// author: Jean-Michel Richer
// email: jean-michel.richer@univ-angers.fr
// ==================================================================

#ifndef VECTOR_SUM_H
#define VECTOR_SUM_H

/**
 * prototype of computation method that will perform 
 * z[i] = a * x[i] + y[i] for all i in [0..size-1]
 */
typedef void (*Kernel)(float a, float *x, float *y, float *z, int size);

/**
 * prototype of procedure that will setup parameters before
 * calling computation method
 */
typedef void (*KernelCaller)();

/**
 * structure to record caller methods
 */
typedef struct {
	const char *name;
	KernelCaller caller;
} Method;


void cudaReportError(char *s);

#ifdef DEBUG
#define CUDA_CHECK(s)  cudaReportError(s)  
#else
#define CUDA_CHECK(s)
#endif

#define X_H vector_h[0]
#define Y_H vector_h[1]
#define Z_H vector_h[2]

#endif

